@@ -232,7 +232,6 @@ signals:
     // Privacy
     void typingNotificationChanged(bool enabled);
     void dbSyncTypeChanged(Db::syncType type);
-    void blackListChanged(QStringList& blist);
 
 public:
     bool applyCommandLineOptions(const QCommandLineParser& parser);
@@ -462,8 +461,14 @@ public:
     // Privacy
     bool getTypingNotification() const;
     void setTypingNotification(bool enabled);
+
     QStringList getBlackList() const override;
     void setBlackList(const QStringList& blist) override;
+    SIGNAL_IMPL(Settings, blackListChanged, QStringList const& blist)
+
+    bool getShowGroupJoinLeaveMessages() const override;
+    void setShowGroupJoinLeaveMessages(bool newValue) override;
+    SIGNAL_IMPL(Settings, showGroupJoinLeaveMessagesChanged, bool show)
 
     // State
     QByteArray getWindowGeometry() const;
@@ -652,6 +657,7 @@ private:
     QString timestampFormat;
     QString dateFormat;
     bool statusChangeNotificationEnabled;
+    bool showGroupJoinLeaveMessages;
     bool spellCheckingEnabled;
 
     // Privacy
